@@ -20,23 +20,13 @@ pub mod sse;
 #[cfg(feature = "tempfile")]
 mod tempfile;
 mod template;
-#[cfg(feature = "typed-headers")]
+#[doc(inline)]
+pub use headers;
 mod typed_header;
 #[cfg(feature = "websocket")]
 #[cfg_attr(docsrs, doc(cfg(feature = "websocket")))]
 pub mod websocket;
 
-/// Commonly used typed headers.
-#[cfg(feature = "typed-headers")]
-#[cfg_attr(docsrs, doc(cfg(feature = "typed-headers")))]
-pub mod type_headers {
-    pub use typed_headers::{
-        Accept, AcceptEncoding, Allow, AuthScheme, Authorization, ContentCoding, ContentEncoding,
-        ContentLength, ContentType, Credentials, Host, HttpDate, ProxyAuthorization, Quality,
-        QualityItem, RetryAfter, Token68,
-    };
-}
-
 use std::convert::{Infallible, TryInto};
 
 use bytes::Bytes;
@@ -52,8 +42,6 @@ pub use query::Query;
 pub use redirect::Redirect;
 pub use remote_addr::RemoteAddr;
 pub use template::{HtmlTemplate, Template};
-#[cfg(feature = "typed-headers")]
-#[cfg_attr(docsrs, doc(cfg(feature = "typed-headers")))]
 pub use typed_header::TypedHeader;
 
 #[cfg(feature = "tempfile")]
@@ -219,7 +207,7 @@ impl RequestBody {
 ///     fmt::{self, Display, Formatter},
 /// };
 ///
-/// use poem::{handler, route, route::get, Endpoint, Error, FromRequest, Request, RequestBody};
+/// use poem::{get, handler, Endpoint, Error, FromRequest, Request, RequestBody, Route};
 ///
 /// struct Token(String);
 ///
@@ -262,7 +250,7 @@ impl RequestBody {
 ///     assert_eq!(token.0, "token123");
 /// }
 ///
-/// let app = route().at("/", get(index));
+/// let app = Route::new().at("/", get(index));
 /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
 /// let _ = index
 ///     .call(Request::builder().header("MyToken", "token123").finish())
@@ -934,7 +922,7 @@ mod tests {
                 .header("Value2", "456")
                 .uri(Uri::from_static("http://example.com/a/b"))
                 .body("abc");
-            req.state_mut().remote_addr = RemoteAddr::new("127.0.0.1:12345");
+            req.state_mut().remote_addr = RemoteAddr::custom("test", "example");
             req
         }
 
@@ -967,7 +955,7 @@ mod tests {
         // &RemoteAddr
         assert_eq!(
             <&RemoteAddr>::from_request(&req, &mut body).await.unwrap(),
-            &RemoteAddr::new("127.0.0.1:12345")
+            &RemoteAddr::custom("test", "example")
         );
 
         // &Method
